Changelog
=========

0.2.6
-----
    - Added @first_or_none() decorator.
    - Fixed #24 - bug in .get_title().
    - Added more test files.

0.2.5
-----
    - Small preventive improvement.

0.2.4
-----
    - Fixed bug in ``MonographPublication.get_year()``.

0.2.3
-----
    - Added requirements to requests.

0.2.2
-----
    - Fixed another bug in build system.

0.2.1
-----
    - Fixed bug in build system.

0.2.0
-----
    - Added docstrings.
    - Added integration tests.
    - Added `sphinx documentation <http://cz-urnnbn-api.readthedocs.org/`_, README.

0.1.0
-----
    - Project created.
